@@ -6,8 +6,8 @@ use Carp;
 use Moo;
 use Types::Standard qw/Str Num Int ArrayRef/;
 
-our $VERSION = '0.0.2'; # VERSION
-# ABSTRACT: Statistics::Cook
+our $VERSION = '0.0.3'; # VERSION
+# ABSTRACT: Statistics::Cook - calculate cook distance of Least squares line fit
 
 
 
@@ -187,11 +187,11 @@ __END__
 
 =head1 NAME
 
-Statistics::Cook - Statistics::Cook
+Statistics::Cook - Statistics::Cook - calculate cook distance of Least squares line fit
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -215,10 +215,6 @@ The module accepts input data in separate x and y arrays. The optional weights a
 The module is state-oriented and caches its results. you can call the other methods in any order
 or call a method several times without invoking redundant calculations.
 
-=head1 NAME
-
-Statistics::Cook - calculate cook distance of Least squares line fit
-
 =head1 LIMITATIONS
 
 The purpose of I write this module is that I could not find a module to calculate cook distance in CPAN,
